pub enum DisplayBehavior {
Clear,
DefaultRedact,
}Variants
Clear
Values of this data class are not redacted and will be displayed in the clear.
DefaultRedact
Values of this data class use default redaction behavior from koek-redact.